==> huaweicloudsdkevs-3.1.47-py2.py3-none-any.whl: huaweicloudsdkevs/v2/model/cinder_list_volume_transfers_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CinderListVolumeTransfersResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'transfers': 'list[VolumeTransferSummary]'
    }

    attribute_map = {
        'transfers': 'transfers'
    }

    def __init__(self, transfers=None):
        """CinderListVolumeTransfersResponse

        The model defined in huaweicloud sdk

        :param transfers: 云硬盘过户记录列表概要，请参见•[transfers参数说明](https://support.huaweicloud.com/api-evs/evs_04_2110.html#evs_04_2110__li6113282511345)。
        :type transfers: list[:class:`huaweicloudsdkevs.v2.VolumeTransferSummary`]
        """
        
        super(CinderListVolumeTransfersResponse, self).__init__()

        self._transfers = None
        self.discriminator = None

        if transfers is not None:
            self.transfers = transfers

    @property
    def transfers(self):
        """Gets the transfers of this CinderListVolumeTransfersResponse.

        云硬盘过户记录列表概要，请参见•[transfers参数说明](https://support.huaweicloud.com/api-evs/evs_04_2110.html#evs_04_2110__li6113282511345)。

        :return: The transfers of this CinderListVolumeTransfersResponse.
        :rtype: list[:class:`huaweicloudsdkevs.v2.VolumeTransferSummary`]
        """
        return self._transfers

    @transfers.setter
    def transfers(self, transfers):
        """Sets the transfers of this CinderListVolumeTransfersResponse.

        云硬盘过户记录列表概要，请参见•[transfers参数说明](https://support.huaweicloud.com/api-evs/evs_04_2110.html#evs_04_2110__li6113282511345)。

        :param transfers: The transfers of this CinderListVolumeTransfersResponse.
        :type transfers: list[:class:`huaweicloudsdkevs.v2.VolumeTransferSummary`]
        """
        self._transfers = transfers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CinderListVolumeTransfersResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkevs-3.1.143-py2.py3-none-any.whl: huaweicloudsdkevs/v2/model/cinder_list_volume_transfers_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CinderListVolumeTransfersResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'transfers': 'list[VolumeTransferSummary]'
    }

    attribute_map = {
        'transfers': 'transfers'
    }

    def __init__(self, transfers=None):
        r"""CinderListVolumeTransfersResponse

        The model defined in huaweicloud sdk

        :param transfers: 云硬盘过户记录列表概要，请参见•[transfers参数说明](https://support.huaweicloud.com/api-evs/evs_04_2110.html#evs_04_2110__li6113282511345)。
        :type transfers: list[:class:`huaweicloudsdkevs.v2.VolumeTransferSummary`]
        """
        
        super(CinderListVolumeTransfersResponse, self).__init__()

        self._transfers = None
        self.discriminator = None

        if transfers is not None:
            self.transfers = transfers

    @property
    def transfers(self):
        r"""Gets the transfers of this CinderListVolumeTransfersResponse.

        云硬盘过户记录列表概要，请参见•[transfers参数说明](https://support.huaweicloud.com/api-evs/evs_04_2110.html#evs_04_2110__li6113282511345)。

        :return: The transfers of this CinderListVolumeTransfersResponse.
        :rtype: list[:class:`huaweicloudsdkevs.v2.VolumeTransferSummary`]
        """
        return self._transfers

    @transfers.setter
    def transfers(self, transfers):
        r"""Sets the transfers of this CinderListVolumeTransfersResponse.

        云硬盘过户记录列表概要，请参见•[transfers参数说明](https://support.huaweicloud.com/api-evs/evs_04_2110.html#evs_04_2110__li6113282511345)。

        :param transfers: The transfers of this CinderListVolumeTransfersResponse.
        :type transfers: list[:class:`huaweicloudsdkevs.v2.VolumeTransferSummary`]
        """
        self._transfers = transfers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CinderListVolumeTransfersResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
